@@ -1314,7 +1314,7 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
         :param _SessionId: 语音段唯一标识，一段完整语音使用一个SessionId，不同语音段的评测需要使用不同的SessionId。一般使用uuid(通用唯一识别码)来作为它的值，要尽量保证SessionId的唯一性。
         :type SessionId: str
         :param _RefText: 被评估语音对应的文本，仅支持中文和英文。
-句子模式下不超过个 30 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式RefText可以不填。
+句子模式下不超过 30个 单词或者中文文字，段落模式不超过 120 个单词或者中文文字，中文评估使用 utf-8 编码，自由说模式RefText可以不填。
 关于RefText的文本键入要求，请参考[评测模式介绍](https://cloud.tencent.com/document/product/884/56131)。
 如需要在评测模式下使用自定义注音（支持中英文），可以通过设置「TextMode」参数实现，设置方式请参考[音素标注](https://cloud.tencent.com/document/product/884/33698)。
         :type RefText: str
@@ -1367,6 +1367,9 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
         :type TextMode: int
         :param _Keyword: 主题词和关键词
         :type Keyword: str
+        :param _COSBucketURL: 音频存储模式，此参数已废弃，无需设置；
+注：有存储需求的用户建议自行存储至腾讯云COS[对象存储](https://cloud.tencent.com/product/cos)使用。
+        :type COSBucketURL: str
         """
         self._SeqId = None
         self._IsEnd = None
@@ -1386,6 +1389,7 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
         self._IsQuery = None
         self._TextMode = None
         self._Keyword = None
+        self._COSBucketURL = None
 
     @property
     def SeqId(self):
@@ -1477,10 +1481,14 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
 
     @property
     def StorageMode(self):
+        warnings.warn("parameter `StorageMode` is deprecated", DeprecationWarning) 
+
         return self._StorageMode
 
     @StorageMode.setter
     def StorageMode(self, StorageMode):
+        warnings.warn("parameter `StorageMode` is deprecated", DeprecationWarning) 
+
         self._StorageMode = StorageMode
 
     @property
@@ -1531,6 +1539,14 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
     def Keyword(self, Keyword):
         self._Keyword = Keyword
 
+    @property
+    def COSBucketURL(self):
+        return self._COSBucketURL
+
+    @COSBucketURL.setter
+    def COSBucketURL(self, COSBucketURL):
+        self._COSBucketURL = COSBucketURL
+
 
     def _deserialize(self, params):
         self._SeqId = params.get("SeqId")
@@ -1551,6 +1567,7 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
         self._IsQuery = params.get("IsQuery")
         self._TextMode = params.get("TextMode")
         self._Keyword = params.get("Keyword")
+        self._COSBucketURL = params.get("COSBucketURL")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -1654,10 +1671,14 @@ class TransmitOralProcessWithInitResponse(AbstractModel):
 
     @property
     def AudioUrl(self):
+        warnings.warn("parameter `AudioUrl` is deprecated", DeprecationWarning) 
+
         return self._AudioUrl
 
     @AudioUrl.setter
     def AudioUrl(self, AudioUrl):
+        warnings.warn("parameter `AudioUrl` is deprecated", DeprecationWarning) 
+
         self._AudioUrl = AudioUrl
 
     @property
